==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Presenters/GenericDocumentRecognizerPresenter.swift <==
//
//  GenericDocumentRecognizerPresenter.swift
//  scanbot_sdk
//
//  Created by Sarbjyot Chahal on 12.01.22.
//

import Foundation
import ScanbotSDK
import Flutter

class GenericDocumentRecognizerPresenter: NSObject {
    private var resultHandler: FlutterResult?
    
    func present(on presenter: UIViewController,
                 with configuration: SBSDKUIGenericDocumentRecognizerConfiguration,
                 result: @escaping FlutterResult) {
        self.resultHandler = result
        let controller = SBSDKUIGenericDocumentRecognizerViewController.createNew(with: configuration, andDelegate: self)
        
        controller.modalPresentationStyle = .fullScreen
        presenter.present(controller, animated: true, completion: nil)
    }
}

extension GenericDocumentRecognizerPresenter: SBSDKUIGenericDocumentRecognizerViewControllerDelegate {
    func genericDocumentRecognizerViewController(_ viewController: SBSDKUIGenericDocumentRecognizerViewController, didFinishWith documents: [SBSDKGenericDocument]) {
        var typeName: String = "";
        var fields = Dictionary<String, Any>()
        
        for document in documents{
            typeName = document.type.name
            for field in document.fields{
                if(field.value?.text != nil){
                    let tempDictionary = [
                        "text":String(field.value?.text ?? ""),
                        "confidence": field.value?.confidence ?? 0
                    ] as [String : Any]
                    fields[field.type.name.localizedLowercase] = tempDictionary
                }
            }
        }
        do {
            let jsonFieldsData = try JSONSerialization.data(withJSONObject: fields)
            
            let jsonFieldsString = String(data: jsonFieldsData, encoding: .utf8)
            let result = [
                "status": "OK",
                "documentType": typeName,
                "fields": jsonFieldsString
            ]
            self.resultHandler?(result.encodedString)
        }catch( let error){
            print(error.localizedDescription)
            self.resultHandler = nil
        }
    }
    
    func scanningViewControllerDidCancel(_ viewController: SBSDKUIDocumentScannerViewController) {
        self.resultHandler?("CANCELED")
        self.resultHandler = nil
    }
}

==> scanbot_sdk-2.12.1.tar.gz: ios/Classes/Presenters/GenericDocumentRecognizerPresenter.swift <==
//
//  GenericDocumentRecognizerPresenter.swift
//  scanbot_sdk
//
//  Created by Sarbjyot Chahal on 12.01.22.
//

import Foundation
import ScanbotSDK
import Flutter

class GenericDocumentRecognizerPresenter: NSObject {
    private var resultHandler: FlutterResult?
    
    func present(on presenter: UIViewController,
                 with configuration: SBSDKUIGenericDocumentRecognizerConfiguration,
                 result: @escaping FlutterResult) {
        self.resultHandler = result
        let controller = SBSDKUIGenericDocumentRecognizerViewController.createNew(with: configuration,
                                                                                  andDelegate: self)
        
        controller.modalPresentationStyle = .fullScreen
        presenter.present(controller, animated: true, completion: nil)
    }
}

extension GenericDocumentRecognizerPresenter: SBSDKUIGenericDocumentRecognizerViewControllerDelegate {
    func genericDocumentRecognizerViewController(_ viewController: SBSDKUIGenericDocumentRecognizerViewController,
                                                 didFinishWith documents: [SBSDKGenericDocument]) {
        
        var fields = [String: Any]()
        for document in documents {
            for field in document.fields {
                if let text = field.value?.text {
                    let tempDictionary = [
                        "text": text,
                        "confidence": field.value?.confidence ?? 0
                    ] as [String: Any]
                    fields[field.type.name.localizedLowercase] = tempDictionary
                }
            }
        }
        
        do {
            let jsonFieldsData = try JSONSerialization.data(withJSONObject: fields)
            
            let jsonFieldsString = String(data: jsonFieldsData, encoding: .utf8)
            let result = [
                "status": "OK",
                "documentType": documents.first?.type.name ?? "",
                "fields": jsonFieldsString
            ]
            self.resultHandler?(result.encodedString)
        } catch(let error) {
            print(error.localizedDescription)
            self.resultHandler = nil
        }
    }
    
    func scanningViewControllerDidCancel(_ viewController: SBSDKUIDocumentScannerViewController) {
        self.resultHandler?("CANCELED")
        self.resultHandler = nil
    }
}
